@@ -12,33 +12,30 @@
  * obtain it through the world-wide-web, please send an email
  * to license@zend.com so we can send you a copy immediately.
  *
+ * @category   Zend
  * @package    Zend_Pdf
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id: Png.php 20096 2010-01-06 02:05:09Z bkarwin $
  */
 
 
+/** Internally used classes */
+require_once 'Zend/Pdf/Element/Array.php';
+require_once 'Zend/Pdf/Element/Dictionary.php';
+require_once 'Zend/Pdf/Element/Name.php';
+require_once 'Zend/Pdf/Element/Numeric.php';
+require_once 'Zend/Pdf/Element/String/Binary.php';
+
+
 /** Zend_Pdf_Resource_Image */
 require_once 'Zend/Pdf/Resource/Image.php';
 
-/** Zend_Pdf_Exception */
-require_once 'Zend/Pdf/Exception.php';
-
-/** Zend_Pdf_Element_Numeric */
-require_once 'Zend/Pdf/Element/Numeric.php';
-
-/** Zend_Pdf_Element_Name */
-require_once 'Zend/Pdf/Element/Name.php';
-
-/** Zend_Pdf_ElementFactory */
-require_once 'Zend/Pdf/ElementFactory.php';
-
-
 /**
  * PNG image
  *
  * @package    Zend_Pdf
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2010 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
@@ -82,6 +79,7 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
     public function __construct($imageFileName)
     {
         if (($imageFile = @fopen($imageFileName, 'rb')) === false ) {
+            require_once 'Zend/Pdf/Exception.php';
             throw new Zend_Pdf_Exception( "Can not open '$imageFileName' file for reading." );
         }
 
@@ -90,6 +88,7 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
         //Check if the file is a PNG
         fseek($imageFile, 1, SEEK_CUR); //First signature byte (%)
         if ('PNG' != fread($imageFile, 3)) {
+            require_once 'Zend/Pdf/Exception.php';
             throw new Zend_Pdf_Exception('Image is not a PNG');
         }
         fseek($imageFile, 12, SEEK_CUR); //Signature bytes (Includes the IHDR chunk) IHDR processed linerarly because it doesnt contain a variable chunk length
@@ -104,6 +103,7 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
         $prefilter = ord(fread($imageFile,1));
 
         if (($interlacing = ord(fread($imageFile,1))) != Zend_Pdf_Resource_Image_Png::PNG_INTERLACING_DISABLED) {
+            require_once 'Zend/Pdf/Exception.php';
             throw new Zend_Pdf_Exception( "Only non-interlaced images are currently supported." );
         }
 
@@ -149,20 +149,27 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
                     switch ($color) {
                         case Zend_Pdf_Resource_Image_Png::PNG_CHANNEL_GRAY:
                             $baseColor = ord(substr($trnsData, 1, 1));
-                            $transparencyData = array(new Zend_Pdf_Element_Numeric($baseColor), new Zend_Pdf_Element_Numeric($baseColor));
+                            $transparencyData = array(new Zend_Pdf_Element_Numeric($baseColor),
+                                                      new Zend_Pdf_Element_Numeric($baseColor));
                             break;
 
                         case Zend_Pdf_Resource_Image_Png::PNG_CHANNEL_RGB:
                             $red = ord(substr($trnsData,1,1));
                             $green = ord(substr($trnsData,3,1));
                             $blue = ord(substr($trnsData,5,1));
-                            $transparencyData = array(new Zend_Pdf_Element_Numeric($red), new Zend_Pdf_Element_Numeric($red), new Zend_Pdf_Element_Numeric($green), new Zend_Pdf_Element_Numeric($green), new Zend_Pdf_Element_Numeric($blue), new Zend_Pdf_Element_Numeric($blue));
+                            $transparencyData = array(new Zend_Pdf_Element_Numeric($red),
+                                                      new Zend_Pdf_Element_Numeric($red),
+                                                      new Zend_Pdf_Element_Numeric($green),
+                                                      new Zend_Pdf_Element_Numeric($green),
+                                                      new Zend_Pdf_Element_Numeric($blue),
+                                                      new Zend_Pdf_Element_Numeric($blue));
                             break;
 
                         case Zend_Pdf_Resource_Image_Png::PNG_CHANNEL_INDEXED:
                             //Find the first transparent color in the index, we will mask that. (This is a bit of a hack. This should be a SMask and mask all entries values).
                             if(($trnsIdx = strpos($trnsData, chr(0))) !== false) {
-                                $transparencyData = array(new Zend_Pdf_Element_Numeric($trnsIdx), new Zend_Pdf_Element_Numeric($trnsIdx));
+                                $transparencyData = array(new Zend_Pdf_Element_Numeric($trnsIdx),
+                                                          new Zend_Pdf_Element_Numeric($trnsIdx));
                             }
                             break;
 
@@ -170,6 +177,7 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
                             // Fall through to the next case
 
                         case Zend_Pdf_Resource_Image_Png::PNG_CHANNEL_RGB_ALPHA:
+                            require_once 'Zend/Pdf/Exception.php';
                             throw new Zend_Pdf_Exception( "tRNS chunk illegal for Alpha Channel Images" );
                             break;
                     }
@@ -200,6 +208,7 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
 
             case Zend_Pdf_Resource_Image_Png::PNG_CHANNEL_INDEXED:
                 if(empty($paletteData)) {
+                    require_once 'Zend/Pdf/Exception.php';
                     throw new Zend_Pdf_Exception( "PNG Corruption: No palette data read for indexed type PNG." );
                 }
                 $colorSpace = new Zend_Pdf_Element_Array();
@@ -217,11 +226,13 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
                  * will become the Shadow Mask (SMask).
                  */
                 if($bits > 8) {
+                    require_once 'Zend/Pdf/Exception.php';
                     throw new Zend_Pdf_Exception("Alpha PNGs with bit depth > 8 are not yet supported");
                 }
 
                 $colorSpace = new Zend_Pdf_Element_Name('DeviceGray');
 
+                require_once 'Zend/Pdf/ElementFactory.php';
                 $decodingObjFactory = Zend_Pdf_ElementFactory::createFactory(1);
                 $decodingStream = $decodingObjFactory->newStreamObject($imageData);
                 $decodingStream->dictionary->Filter      = new Zend_Pdf_Element_Name('FlateDecode');
@@ -250,11 +261,13 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
                  * will become the Shadow Mask (SMask).
                  */
                 if($bits > 8) {
+                    require_once 'Zend/Pdf/Exception.php';
                     throw new Zend_Pdf_Exception("Alpha PNGs with bit depth > 8 are not yet supported");
                 }
 
                 $colorSpace = new Zend_Pdf_Element_Name('DeviceRGB');
 
+                require_once 'Zend/Pdf/ElementFactory.php';
                 $decodingObjFactory = Zend_Pdf_ElementFactory::createFactory(1);
                 $decodingStream = $decodingObjFactory->newStreamObject($imageData);
                 $decodingStream->dictionary->Filter      = new Zend_Pdf_Element_Name('FlateDecode');
@@ -278,10 +291,12 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
                 break;
 
             default:
+                require_once 'Zend/Pdf/Exception.php';
                 throw new Zend_Pdf_Exception( "PNG Corruption: Invalid color space." );
         }
 
         if(empty($imageData)) {
+            require_once 'Zend/Pdf/Exception.php';
             throw new Zend_Pdf_Exception( "Corrupt PNG Image. Mandatory IDAT chunk not found." );
         }
 
@@ -291,11 +306,11 @@ class Zend_Pdf_Resource_Image_Png extends Zend_Pdf_Resource_Image
              * Includes the Alpha transparency data as a Gray Image, then assigns the image as the Shadow Mask for the main image data.
              */
             $smaskStream = $this->_objectFactory->newStreamObject($smaskData);
-            $smaskStream->dictionary->Type = new Zend_Pdf_Element_Name('XObject');
-            $smaskStream->dictionary->Subtype = new Zend_Pdf_Element_Name('Image');
-            $smaskStream->dictionary->Width = new Zend_Pdf_Element_Numeric($width);
-            $smaskStream->dictionary->Height = new Zend_Pdf_Element_Numeric($height);
-            $smaskStream->dictionary->ColorSpace = new Zend_Pdf_Element_Name('DeviceGray');
+            $smaskStream->dictionary->Type             = new Zend_Pdf_Element_Name('XObject');
+            $smaskStream->dictionary->Subtype          = new Zend_Pdf_Element_Name('Image');
+            $smaskStream->dictionary->Width            = new Zend_Pdf_Element_Numeric($width);
+            $smaskStream->dictionary->Height           = new Zend_Pdf_Element_Numeric($height);
+            $smaskStream->dictionary->ColorSpace       = new Zend_Pdf_Element_Name('DeviceGray');
             $smaskStream->dictionary->BitsPerComponent = new Zend_Pdf_Element_Numeric($bits);
             $imageDictionary->SMask = $smaskStream;
 
